==> ejc-jlincome-api-3.0.0-20240516.061603-88-sources.jar: com/ejianc/business/jlincome/income/vo/DisclosureDepDetailsVO.java <==
package com.ejianc.business.jlincome.income.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 收入管理-合同交底-部门明细子表
 * 
 * @author generator
 * 
 */
public class DisclosureDepDetailsVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long disclosureId; // 主表主键ID
    private Long disclosureTypeId; // 交底类型
    private String disclosureTypeName; // 交底类型名称
    private String disclosureDepartments; // 交底参与部门
    private String departmentPeople; // 部门负责人
    private String disclosureOpinion; // 交底意见
    private String memo; // 备注
    

    public Long getDisclosureId() {
        return disclosureId;
    }

    public void setDisclosureId(Long disclosureId) {
        this.disclosureId = disclosureId;
    }
    @ReferSerialTransfer(referCode = "support-defdoc")
    public Long getDisclosureTypeId() {
        return disclosureTypeId;
    }
    @ReferDeserialTransfer
    public void setDisclosureTypeId(Long disclosureTypeId) {
        this.disclosureTypeId = disclosureTypeId;
    }
    public String getDisclosureTypeName() {
        return disclosureTypeName;
    }

    public void setDisclosureTypeName(String disclosureTypeName) {
        this.disclosureTypeName = disclosureTypeName;
    }
    public String getDisclosureDepartments() {
        return disclosureDepartments;
    }

    public void setDisclosureDepartments(String disclosureDepartments) {
        this.disclosureDepartments = disclosureDepartments;
    }
    public String getDepartmentPeople() {
        return departmentPeople;
    }

    public void setDepartmentPeople(String departmentPeople) {
        this.departmentPeople = departmentPeople;
    }
    public String getDisclosureOpinion() {
        return disclosureOpinion;
    }

    public void setDisclosureOpinion(String disclosureOpinion) {
        this.disclosureOpinion = disclosureOpinion;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-jlincome-api-3.0.0-20241105.091410-320-sources.jar: com/ejianc/business/jlincome/income/vo/DisclosureDepDetailsVO.java <==
package com.ejianc.business.jlincome.income.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 收入管理-合同交底-部门明细子表
 * 
 * @author generator
 * 
 */
public class DisclosureDepDetailsVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long disclosureId; // 主表主键ID

    private String disclosureType; //交底类型

    private String disclosureDepartments; // 交底参与部门

    private String departmentPeopleId;//部门负责人id

    private String departmentPeopleName;//部门负责人名称
    private String disclosureOpinion; // 交底意见
    private String memo; // 备注

    public String getDisclosureType() {
        return disclosureType;
    }

    public void setDisclosureType(String disclosureType) {
        this.disclosureType = disclosureType;
    }
    @ReferSerialTransfer(referCode = "idm-employee")
    public String getDepartmentPeopleId() {
        return departmentPeopleId;
    }
    @ReferDeserialTransfer
    public void setDepartmentPeopleId(String departmentPeopleId) {
        this.departmentPeopleId = departmentPeopleId;
    }

    public String getDepartmentPeopleName() {
        return departmentPeopleName;
    }

    public void setDepartmentPeopleName(String departmentPeopleName) {
        this.departmentPeopleName = departmentPeopleName;
    }

    public Long getDisclosureId() {
        return disclosureId;
    }

    public void setDisclosureId(Long disclosureId) {
        this.disclosureId = disclosureId;
    }


    public String getDisclosureDepartments() {
        return disclosureDepartments;
    }

    public void setDisclosureDepartments(String disclosureDepartments) {
        this.disclosureDepartments = disclosureDepartments;
    }

    public String getDisclosureOpinion() {
        return disclosureOpinion;
    }

    public void setDisclosureOpinion(String disclosureOpinion) {
        this.disclosureOpinion = disclosureOpinion;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
